from dynamic_url import Url
from google.cloud import bigquery

db = bigquery.Client()

dic = {
    "Origin": "https://bsti-telehealth-3040f7f35c4f4a0-b7lefc4bya-uc.a.run.app/"
}
url_obj = Url()
url_validate = url_obj.get_url(dic, db)



from google.cloud import bigquery


class Querys:
    def __init__(self, appointment_id):
        self.appointment_id = appointment_id

    def from_telehealth_room_url(self):
        query = """
            SELECT telehealth_room_url AS url FROM
        `crx-prod-btsi.NY_BSTI_Dev.Telehealth_Room_URL`
        WHERE appointment_id = @appointment_id
        LIMIT 1"""

        # Set the name to None to use positional parameters.
        # Note that you cannot mix named and positional parameters.
        # Based in cloud bigquery documentation.
        job_config = bigquery.QueryJobConfig(
            query_parameters=[
                bigquery.ScalarQueryParameter(
                    "appointment_id", "STRING", self.appointment_id
                )
            ]
        )

        return query, job_config



# -*- coding: utf-8 -*-
from .functions import Querys


class Url:
    def get_url(self, headers, db):
        """Check the appoimentID from the url
            Match with the database to validate if exist

            Args:
                headers ([type]): [Headers Objec]

            Returns:
                url [string]: [url validate]
            """

        try:
            url_origin = headers.get("Origin", False)
            appointment_id = url_origin.split("-")[2]
            query_functions = Querys(appointment_id)
            query, job_config = query_functions.from_telehealth_room_url()
            df = db.query(query, job_config=job_config).to_dataframe()
            url = df.url[0] if not df.empty else ""
        except IndexError:
            url = ""
        except AttributeError:
            url = ""

        return url



# -*- coding: utf-8 -*-
import unittest
from dynamic_url import Url


class TestParams(unittest.TestCase):
    array_test = ["Origin"]
    dict_test = {"Origin": "test"}
    dict_test2 = {"Not_Origin": "test"}
    dict_test3 = {"Origin": "https://www.google.com/"}
    dict_test4 = {"Origin": ""}

    def test_get_url_two_params(self):
        self.assertEqual(
            Url().get_url("hola", "db"), "", "Error in params -> two strings"
        )
        self.assertEqual(
            Url().get_url("", ""), "", "Error in params -> two empty strings"
        )

    def test_get_url_array_params(self):
        self.assertEqual(
            Url().get_url(self.array_test, "db"),
            "",
            "Error in params with array",
        )

    def test_get_url_dict_params(self):
        self.assertEqual(
            Url().get_url(self.dict_test, "db"),
            "",
            "Error in params with array",
        )
        self.assertEqual(
            Url().get_url(self.dict_test2, db={"db": ""}),
            "",
            "Error in params with array",
        )
        self.assertEqual(
            Url().get_url(self.dict_test3, "db"),
            "",
            "Error in params with array",
        )
        self.assertEqual(
            Url().get_url(self.dict_test4, "db"),
            "",
            "Error in params with array",
        )


if __name__ == "__main__":
    unittest.main()



# Always prefer setuptools over distutils
from setuptools import setup

# To use a consistent encoding
from codecs import open
from os import path

# The directory containing this file
HERE = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(HERE, "README.md"), encoding="utf-8") as f:
    long_description = f.read()


classifiers = [
    "Intended Audience :: Developers",
    "Development Status :: 5 - Production/Stable",
    "License :: OSI Approved :: MIT License",
    "Programming Language :: Python",
    "Programming Language :: Python :: 3",
    "Programming Language :: Python :: 3.6",
    "Programming Language :: Python :: 3.7",
    "Programming Language :: Python :: 3.8",
    "Programming Language :: Python :: 3.9",
    "Operating System :: OS Independent",
]

setup(
    name="getDynamicUrl",
    version="0.0.6",
    license="MIT",
    description="Get dyanmic Url",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="",
    author="Jhone Mendez",
    author_email="jhone0901@gmail.com",
    classifiers=classifiers,
    packages=["dynamic_url"],
    keywords="dynamicUrl",
    install_requires=["google-cloud-bigquery", "pyarrow"],
)
